aboutsummaryrefslogtreecommitdiff
path: root/video/dxa_decoder.h
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/dxa_decoder.h
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/dxa_decoder.h')
-rw-r--r--video/dxa_decoder.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/video/dxa_decoder.h b/video/dxa_decoder.h
index e2fa97a7db..e480298a90 100644
--- a/video/dxa_decoder.h
+++ b/video/dxa_decoder.h
@@ -28,7 +28,7 @@
#include "video/video_decoder.h"
-namespace Graphics {
+namespace Video {
/**
* Decoder for DXA videos.
@@ -50,8 +50,8 @@ public:
uint16 getWidth() const { return _width; }
uint16 getHeight() const { return _height; }
uint32 getFrameCount() const { return _frameCount; }
- const Surface *decodeNextFrame();
- PixelFormat getPixelFormat() const { return PixelFormat::createFormatCLUT8(); }
+ const Graphics::Surface *decodeNextFrame();
+ Graphics::PixelFormat getPixelFormat() const { return Graphics::PixelFormat::createFormatCLUT8(); }
const byte *getPalette() { _dirtyPalette = false; return _palette; }
bool hasDirtyPalette() const { return _dirtyPalette; }
@@ -96,6 +96,6 @@ private:
uint32 _frameCount;
};
-} // End of namespace Graphics
+} // End of namespace Video
#endif